==> nagioslogserver-2026R1.0.1.tar.gz: nagioslogserver/nagioslogserver/basedir/html/application/views/admin/index_status.php <==
<?php echo $header; ?>
<div class="configure-layout">
    <?php echo $leftbar; ?>
    <div class="form-container">

        <h1 class="form-title"><?php echo ($index['stats']['count'] != 1 ) ? _("Index Overview") : _("Index") . " &middot; [ " . key($index['stats']['indices']) . " ]"; ?></h1>
        <div class="form-spacer"></div>
        <div id="workspace">
            <div class="alert alert-info hide" id="indices_opening"><?php echo sprintf(_('Some indices are still opening. %1$s of %2$s remaining'), '<div id="indices_opening_remaining" style="display: inline"></div>', '<div id="indices_opening_total" style="display: inline"></div>');?>
            </div>
            <div>
                <div>
                    <div class="tw-my-4">
                        <div class="tw-flex tw-gap-2 tw-items-center tw-mb-2">
                            <i class="fa fa-bar-chart"></i>
                            <span class="form-header"><?php echo _("Index Statistics"); ?></span>
                        </div>
                        <div class="tw-rounded-lg tw-border-border tw-border tw-p-4 tw-overflow-auto">
                            <div class="row">
                                <div class="col-sm-12 col-md-6 col-lg-4 stat-box-wrap">
                                    <div class="tw-text-center tw-p-5 tw-border tw-border-border tw-rounded-lg"><span class="stat-detail"><?php echo number_format($index['stats']['_all']['primaries']['docs']['count']); ?></span><span><?php echo _("Documents"); ?></span></div>
                                </div>
                                <div class="col-sm-12 col-md-6 col-lg-4 stat-box-wrap">
                                    <div class="tw-text-center tw-p-5 tw-border tw-border-border tw-rounded-lg"><span class="stat-detail"><?php echo $index['stats']['_shards']['total']; ?></span><span><?php echo _("Total Shards"); ?></span></div>
                                </div>
                                <div class="col-sm-12 col-md-6 col-lg-4 stat-box-wrap">
                                    <div class="tw-text-center tw-p-5 tw-border tw-border-border tw-rounded-lg"><span class="stat-detail"><?php echo $index['stats']['_shards']['successful']; ?></span><span><?php echo _("Successful Shards"); ?></span></div>
                                </div>
                                <div class="col-sm-12 col-md-6 col-lg-4 stat-box-wrap">
                                    <div class="tw-text-center tw-p-5 tw-border tw-border-border tw-rounded-lg"><span class="stat-detail"><?php echo $index['stats']['count']; ?></span><span><?php echo _("Indices"); ?></span></div>
                                </div>
                                <div class="col-sm-12 col-md-6 col-lg-4 stat-box-wrap">
                                    <div class="tw-text-center tw-p-5 tw-border tw-border-border tw-rounded-lg"><span class="stat-detail"><?php echo strtoupper($index['stats']['_all']['primaries']['store']['size']); ?></span><span><?php echo _("Primary Size"); ?></span></div>
                                </div>
                                <div class="col-sm-12 col-md-6 col-lg-4 stat-box-wrap">
                                    <div class="tw-text-center tw-p-5 tw-border tw-border-border tw-rounded-lg"><span class="stat-detail"><?php echo strtoupper($index['stats']['_all']['total']['store']['size']); ?></span><span><?php echo _("Total Size"); ?></span></div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div>
                <?php echo $indices_table; ?>
            </div>
        </div>

    </div>
</div>

<?php echo $footer; ?>

==> nagioslogserver-2026R1.0.2.tar.gz: nagioslogserver/nagioslogserver/basedir/html/application/views/admin/index_status.php <==
<?php echo $header; ?>
<div class="configure-layout">
    <?php echo $leftbar; ?>
    <div class="form-container">

        <h1 class="form-title"><?php echo ($index['stats']['count'] != 1 ) ? _("Index Overview") : _("Index") . " &middot; [ " . key($index['stats']['indices']) . " ]"; ?></h1>
        <div class="form-spacer"></div>
        <div id="workspace">
            <div class="alert alert-info hide" id="indices_opening"><?php echo sprintf(_('Some indices are still opening. %1$s of %2$s remaining'), '<div id="indices_opening_remaining" style="display: inline"></div>', '<div id="indices_opening_total" style="display: inline"></div>');?>
            </div>
            <div>
                <div>
                    <div class="tw-my-4">
                        <div class="tw-flex tw-gap-2 tw-items-center tw-mb-2">
                            <i class="fa fa-bar-chart"></i>
                            <span class="form-header"><?php echo _("Index Statistics"); ?></span>
                        </div>
                        <div class="tw-rounded-lg tw-border-border tw-border tw-p-4 tw-overflow-auto">
                            <div class="row">
                                <div class="col-sm-12 col-md-6 col-lg-4 stat-box-wrap">
                                    <div class="tw-text-center tw-p-5 tw-border tw-border-border tw-rounded-lg"><span class="stat-detail"><?php echo number_format($index['stats']['logstash_doc_count']); ?></span><span><?php echo _("Log Entries in Open Indices"); ?></span></div>
                                </div>
                                <div class="col-sm-12 col-md-6 col-lg-4 stat-box-wrap">
                                    <div class="tw-text-center tw-p-5 tw-border tw-border-border tw-rounded-lg"><span class="stat-detail"><?php echo number_format($index['stats']['_all']['primaries']['docs']['count']); ?></span><span><?php echo _("Total Documents"); ?></span></div>
                                </div>
                                <div class="col-sm-12 col-md-6 col-lg-4 stat-box-wrap">
                                    <div class="tw-text-center tw-p-5 tw-border tw-border-border tw-rounded-lg"><span class="stat-detail"><?php echo $index['stats']['_shards']['total']; ?></span><span><?php echo _("Total Shards"); ?></span></div>
                                </div>
                                <div class="col-sm-12 col-md-6 col-lg-4 stat-box-wrap">
                                    <div class="tw-text-center tw-p-5 tw-border tw-border-border tw-rounded-lg"><span class="stat-detail"><?php echo $index['stats']['_shards']['successful']; ?></span><span><?php echo _("Successful Shards"); ?></span></div>
                                </div>
                                <div class="col-sm-12 col-md-6 col-lg-4 stat-box-wrap">
                                    <div class="tw-text-center tw-p-5 tw-border tw-border-border tw-rounded-lg"><span class="stat-detail"><?php echo $index['stats']['count']; ?></span><span><?php echo _("Logstash Indices"); ?></span></div>
                                </div>
                                <div class="col-sm-12 col-md-6 col-lg-4 stat-box-wrap">
                                    <div class="tw-text-center tw-p-5 tw-border tw-border-border tw-rounded-lg"><span class="stat-detail"><?php echo strtoupper($index['stats']['_all']['primaries']['store']['size']); ?></span><span><?php echo _("Primary Size"); ?></span></div>
                                </div>
                                <div class="col-sm-12 col-md-6 col-lg-4 stat-box-wrap">
                                    <div class="tw-text-center tw-p-5 tw-border tw-border-border tw-rounded-lg"><span class="stat-detail"><?php echo strtoupper($index['stats']['_all']['total']['store']['size']); ?></span><span><?php echo _("Total Size"); ?></span></div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div>
                <?php echo $indices_table; ?>
            </div>
        </div>

    </div>
</div>

<?php echo $footer; ?>
